aboutsummaryrefslogtreecommitdiff
path: root/i3-input
diff options
context:
space:
mode:
authorMichael Stapelberg <michael@stapelberg.de>2016-02-01 09:42:55 +0100
committerMichael Stapelberg <michael@stapelberg.de>2016-02-06 10:36:43 +0100
commitfbfbdb8e124480bc90bbd6a8b59c1692c4ebd531 (patch)
treeeebf7b973fa4e6c31650ed8907072bd82eb1c752 /i3-input
parent065ce6b8fcd3510033d81f5f3731a765e1324b91 (diff)
downloadi3-fbfbdb8e124480bc90bbd6a8b59c1692c4ebd531.tar.gz
i3-fbfbdb8e124480bc90bbd6a8b59c1692c4ebd531.zip
travis: check spelling of binaries and manpages, use docker
We now build a docker base container based on debian sid (where the very latest packages are available). That base container is updated once a month, or whenever travis-build.Dockerfile or debian/control change, but re-used for subsequent travis runs. While the initial build might take up to 15 minutes, subsequent builds typically run in a minute or two. All the different steps that we run on travis are now factored into separate scripts in the travis/ directory. Switching to docker should also help with issue #2174.
Diffstat (limited to 'i3-input')
-rw-r--r--i3-input/main.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/i3-input/main.c b/i3-input/main.c
index e196891c..64a089dd 100644
--- a/i3-input/main.c
+++ b/i3-input/main.c
@@ -176,14 +176,14 @@ static int handle_key_release(void *ignored, xcb_connection_t *conn, xcb_key_rel
static void finish_input() {
char *command = (char *)concat_strings(glyphs_utf8, input_position);
/* count the occurences of %s in the string */
int c;
int len = strlen(format);
int cnt = 0;
for (c = 0; c < (len - 1); c++)
if (format[c] == '%' && format[c + 1] == 's')
cnt++;
- printf("occurences = %d\n", cnt);
+ printf("occurrences = %d\n", cnt);
/* allocate space for the output */
int inputlen = strlen(command);
@@ -176,14 +176,14 @@ static int handle_key_release(void *ignored, xcb_connection_t *conn, xcb_key_rel
static void finish_input() {
char *command = (char *)concat_strings(glyphs_utf8, input_position);
- /* count the occurences of %s in the string */
+ /* count the occurrences of %s in the string */
int c;
int len = strlen(format);